======
pymapd
======

.. image:: https://travis-ci.org/omnisci/pymapd.svg?branch=master
   :target: https://travis-ci.org/omnisci/pymapd


.. image:: https://readthedocs.org/projects/pymapd/badge/?version=latest
   :target: http://pymapd.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

A python `DB API`_ compliant interface for `OmniSci`_ (formerly MapD). See the
`documentation`_ for more.

Quick Install
-------------

Packages are available on conda-forge and PyPI::

   conda install -c conda-forge pymapd



.. _DB API: https://www.python.org/dev/peps/pep-0249/
.. _OmniSci: https://www.omnisci.com/
.. _documentation: http://pymapd.readthedocs.io/en/latest/?badge=latest
